@@ -55,6 +55,9 @@ class AppiumOptions(
             'setWindowRect',
             'timeouts',
             'unhandledPromptBehavior',
+            'strictFileInteractability',  # WebDriver spec v2 https://www.w3.org/TR/webdriver2/
+            'userAgent',  # WebDriver spec v2 https://www.w3.org/TR/webdriver2/
+            'webSocketUrl',  # WebDriver BiDi
         ]
     )
     _OSS_W3C_CONVERSION = {
@@ -69,7 +72,7 @@ class AppiumOptions(
         # FIXME: https://github.com/SeleniumHQ/selenium/issues/10755
         self._ignore_local_proxy = False
 
-    def set_capability(self: T, name: str, value: Any) -> T:
+    def set_capability(self: T, name: str, value: Any) -> T:  # type: ignore[override]
         w3c_name = name if name in self.W3C_CAPABILITY_NAMES or ':' in name else f'{APPIUM_PREFIX}{name}'
         if value is None:
             if w3c_name in self._caps:
